@@ -12,13 +12,9 @@ use WWW::Desk::Browser;
 
 WWW::Desk - Desk.com perl API
 
-=head1 VERSION
-
-Version 0.09
-
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -77,7 +73,7 @@ has 'browser_client' => (
 
 sub _build_browser_client {
     my ($self) = @_;
-    return WWW::Desk::Browser->new( base_url => $self->desk_url );
+    return WWW::Desk::Browser->new(base_url => $self->desk_url);
 }
 
 =head2 authentication
@@ -104,19 +100,17 @@ you can also pass params next to http method to add additional paramerters to th
 =cut
 
 sub call {
-    my ( $self, $url_fragment, $http_method, $params ) = @_;
+    my ($self, $url_fragment, $http_method, $params) = @_;
 
-    if ( not defined $params ) {
-        $params = { 't' => time() };
+    if (not defined $params) {
+        $params = {'t' => time()};
     }
 
-    return $self->_prepare_response( "400",
-        "Argument must be supplied as HASH" )
-      unless ref $params eq 'HASH';
+    return $self->_prepare_response("400", "Argument must be supplied as HASH")
+        unless ref $params eq 'HASH';
 
-    return $self->_prepare_response( "400",
-        "Invalid HTTP method. Only supported GET, POST, PATCH, DELETE" )
-      unless $http_method =~ /^GET$|^POST$|^PATCH$|^DELETE$/i;
+    return $self->_prepare_response("400", "Invalid HTTP method. Only supported GET, POST, PATCH, DELETE")
+        unless $http_method =~ /^GET$|^POST$|^PATCH$|^DELETE$/i;
 
     $http_method = lc $http_method;
     my $browser_client = $self->browser_client;
@@ -125,39 +119,30 @@ sub call {
     my $response;
 
     my $authentication = $self->authentication;
-    if ( ref($authentication) eq 'WWW::Desk::Auth::HTTP' ) {
+    if (ref($authentication) eq 'WWW::Desk::Auth::HTTP') {
 
-        my $json_params =
-          $params ? $browser_client->js_encode($params) : $params;
+        my $json_params = $params ? $browser_client->js_encode($params) : $params;
         my $http_headers = $self->authentication->login_headers->to_hash();
-        $response =
-          $browser_client->browser->$http_method(
-            $request_url => $http_headers => $json_params );
-    }
-    elsif ( ref($authentication) eq 'WWW::Desk::Auth::oAuth' ) {
-        return $self->_prepare_response( "501",
-            "Command line doesn't support oAuth Authentication" );
-    }
-    else {
-        return $self->_prepare_response( "501",
-            "Authentication Not Implemented" );
+        $response = $browser_client->browser->$http_method($request_url => $http_headers => $json_params);
+    } elsif (ref($authentication) eq 'WWW::Desk::Auth::oAuth') {
+        return $self->_prepare_response("501", "Command line doesn't support oAuth Authentication");
+    } else {
+        return $self->_prepare_response("501", "Authentication Not Implemented");
     }
 
     my $error = $response->error;
 
-    return $self->_prepare_response( 404, $error )
-	if ref $error ne 'HASH';
+    return $self->_prepare_response(404, $error)
+        if ref $error ne 'HASH';
 
-    return $self->_prepare_response( $error->{'code'} || 408,
-        $error->{'message'} )
-      if $error;
+    return $self->_prepare_response($error->{'code'} || 408, $error->{'message'})
+        if $error;
 
-    return $self->_prepare_response( 200,
-        'OK', $response->res->body );
+    return $self->_prepare_response(200, 'OK', $response->res->body);
 }
 
 sub _prepare_response {
-    my ( $self, $code, $msg, $data ) = @_;
+    my ($self, $code, $msg, $data) = @_;
     $data = $self->browser_client->js_decode($data) if $data;
     return {
         'code'    => $code,
@@ -211,48 +196,6 @@ L<http://search.cpan.org/dist/WWW-Desk/>
 
 =head1 ACKNOWLEDGEMENTS
 
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2014 binary.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-
 =cut
 
 no Moose;
