@@ -14,13 +14,9 @@ use Tie::Hash::LRU;
 
 WWW::Desk::Auth::oAuth - Desk.com oAuth Authentication
 
-=head1 VERSION
-
-Version 0.02
-
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.10';    ## VERSION
 
 our %session;
 our $lru = tie %session, 'Tie::Hash::LRU', 100;
@@ -84,13 +80,12 @@ debug oAuth Requests - boolean type
 =cut
 
 has 'debug' => (
-    is       => 'ro',
-    isa      => 'Bool',
-    lazy     => 1,
-    default  => sub {
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub {
         return 0;
-    }
-);
+    });
 
 =head2 api_version
 
@@ -104,8 +99,7 @@ has 'api_version' => (
     lazy    => 1,
     default => sub {
         return "v2";
-    }
-);
+    });
 
 =head2 auth_client
 
@@ -130,15 +124,15 @@ sub _build_auth_client {
         request_token_path => '/oauth/request_token',
         access_token_path  => '/oauth/access_token',
         callback           => $self->callback_url,
-        session 	       => \&_session,
+        session            => \&_session,
         debug              => $self->debug
     );
 }
 
-sub _session{
-    my ( @data ) = @_;
-    if ( $data[0] && $data[1] ) {
-        %session = ( $data[0] => $data[1] );
+sub _session {
+    my (@data) = @_;
+    if ($data[0] && $data[1]) {
+        %session = ($data[0] => $data[1]);
         return %session;
     }
     return $session{$data[0]};
@@ -158,8 +152,9 @@ sub _session{
     # Visit authorization_url, approve it
     $auth->authorization_url;
 
+    my $params; # get params from cgi
     # Use the auth code to fetch the access token
-    my $access_token =  $auth->request_access_token(params->{oauth_token}, params->{oauth_verifier});
+    my $access_token =  $auth->request_access_token($params->{oauth_token}, $params->{oauth_verifier});
 
     # Use the access token to fetch a protected resource
     my $response = $access_token->get( $auth->build_api_url('/customers') );
@@ -171,7 +166,7 @@ NOTE: Checkout demo/oAuth_demo.pl for oauth demo application
 
 =head2 authorization_url
 
-Authorization url the user needs to visit to authorize 
+Authorization url the user needs to visit to authorize
 
 =cut
 
@@ -194,7 +189,7 @@ It accept two parameters $oauth_token, $oauth_verifier.
 
 sub request_access_token {
     my ($self, $oauth_token, $oauth_verifier) = @_;
-    $self->{'oauth_token'} = $oauth_token;
+    $self->{'oauth_token'}    = $oauth_token;
     $self->{'oauth_verifier'} = $oauth_verifier;
     return $self->auth_client->get_access_token($oauth_token, $oauth_verifier);
 }
@@ -208,13 +203,11 @@ Takes path as input format
 =cut
 
 sub build_api_url {
-    my ( $self, $path ) = @_;
+    my ($self, $path) = @_;
     my $api_version = $self->api_version;
     my $new_path    = Mojo::Path->new($path);
     $path = $new_path->leading_slash(0);
-    my $url =
-      Mojo::URL->new( $self->desk_url )->path("/api/$api_version/$path")
-      ->to_abs();
+    my $url = Mojo::URL->new($self->desk_url)->path("/api/$api_version/$path")->to_abs();
     return $url;
 }
 
@@ -260,48 +253,6 @@ L<http://search.cpan.org/dist/WWW-Desk/>
 
 =head1 ACKNOWLEDGEMENTS
 
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2014 binary.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-
 =cut
 
 no Moose;
